@@ -5,3 +5,5 @@ from .factories import *
 from .getFnames import getInitForAllTabs
 from .managers import *
 from .startConsole import startConsole
+from .methods import *
+from .robust_logger import *
